@@ -16,26 +16,34 @@
 # You should have received a copy of the GNU General Public License
 # along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
 
-if [ -z "$V" -o "$V0" = 0 ]; then
+LOG=
+if [ -z "$V" -o "$V" = 0 ]; then
     trace () {
         echo "  $1"
         shift
-        eval "$@" $LOG
+        echo "$@" >> build.log
+        eval "$@ $LOG"
+        cat .log 1>&2
+        cat .log >> build.log
     }
-    LOG=" >>build.log 2>&1"
+    LOG=" >.log 2>&1"
 fi
 if [ "$V" = 1 ]; then
     trace () {
         shift
         echo "$@"
+        echo "$@" >> build.log
         eval "$@ $LOG"
+        cat .log 1>&2
+        cat .log >> build.log
     }
-    LOG=" >>build.log 2>&1"
+    LOG=" >.log 2>&1"
 fi
 if [ "$V" = 2 ]; then
     set -x
     trace () {
         shift
+        echo "$@" >> build.log
         eval "$@"
     }
 fi
