@@ -1,6 +1,8 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
+ * Copyright © 2023 Emily Trau <emily@downunderctf.com>
  *
  * This file is part of GNU Mes.
  *
@@ -40,12 +42,17 @@
 #define O_APPEND      0x400
 
 #ifdef __arm__
-#define O_DIRECTORY 0x4000
-/*#define O_DIRECT 0x10000*/
+#define O_DIRECTORY   0x4000
+#define O_TMPFILE   0x404000
 #else
-#define O_DIRECTORY 0x10000
+#define O_DIRECTORY  0x10000
+#define O_TMPFILE   0x410000
 #endif
 
+#define AT_FDCWD            -100
+#define AT_SYMLINK_NOFOLLOW  0x100
+#define AT_REMOVEDIR         0x200
+
 #elif __GNU__
 #define	O_RDONLY	  1
 #define	O_WRONLY	  2
@@ -69,8 +76,11 @@
 #define creat(file_name, mode) open (file_name, O_WRONLY | O_CREAT | O_TRUNC, mode)
 int dup (int old);
 int dup2 (int old, int new);
+
+#if !__M2__
 int fcntl (int filedes, int command, ...);
 int open (char const *s, int flags, ...);
+#endif
 
 #endif // ! SYSTEM_LIBC
 
