@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2022,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -22,4 +22,9 @@
 
 #include <arch/syscall.h>
 
+struct stat
+{
+  mode_t st_mode;
+};
+
 #endif // __MES_GNU_X86_KERNEL_STAT_H
