@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020,2022,2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2022,2023 Timothy Sample <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
  *
@@ -53,9 +54,10 @@ struct scm *write_port_ (struct scm *x, struct scm *p);
 struct scm *pairlis (struct scm *x, struct scm *y, struct scm *a);
 struct scm *set_car_x (struct scm *x, struct scm *e);
 struct scm *set_cdr_x (struct scm *x, struct scm *e);
-struct scm *set_env_x (struct scm *x, struct scm *e, struct scm *a);
 struct scm *add_formals (struct scm *formals, struct scm *x);
 struct scm *eval_apply ();
+struct scm *primitive_load (struct scm *filename);
+struct scm *make_binding (struct scm *name, struct scm *variable);
 /* src/gc.c */
 struct scm *gc_stats ();
 struct scm *cons (struct scm *x, struct scm *y);
@@ -64,13 +66,19 @@ struct scm *gc ();
 /* src/hash.c */
 struct scm *hashq (struct scm *x, struct scm *size);
 struct scm *hash (struct scm *x, struct scm *size);
-struct scm *hashq_get_handle (struct scm *table, struct scm *key, struct scm *dflt);
-struct scm *hashq_ref (struct scm *table, struct scm *key, struct scm *dflt);
-struct scm *hash_ref (struct scm *table, struct scm *key, struct scm *dflt);
+struct scm *hashq_get_handle (struct scm *table, struct scm *key);
+struct scm *hashq_ref_ (struct scm *table, struct scm *key, struct scm *dflt);
+struct scm *hash_ref_ (struct scm *table, struct scm *key, struct scm *dflt);
+struct scm *hashq_create_handle_x (struct scm *table, struct scm *key, struct scm *init);
+struct scm *hash_create_handle_x (struct scm *table, struct scm *key, struct scm *init);
 struct scm *hashq_set_x (struct scm *table, struct scm *key, struct scm *value);
 struct scm *hash_set_x (struct scm *table, struct scm *key, struct scm *value);
+struct scm *hash_remove_x (struct scm *table, struct scm *key);
 struct scm *hash_table_printer (struct scm *table);
 struct scm *make_hash_table (struct scm *x);
+struct scm *hash_buckets (struct scm *table);
+struct scm *hash_table_p (struct scm *x);
+struct scm *hash_clear_x (struct scm *table);
 /* src/lib.c */
 struct scm *type_ (struct scm *x);
 struct scm *car_ (struct scm *x);
@@ -82,6 +90,9 @@ struct scm *last_pair (struct scm *x);
 struct scm *pair_p (struct scm *x);
 struct scm *char_to_integer (struct scm *x);
 struct scm *integer_to_char (struct scm *x);
+struct scm *make_bytevector (struct scm *args);
+struct scm *bytevector_u8_ref (struct scm *bv, struct scm *k);
+struct scm *bytevector_u8_set_x (struct scm *bv, struct scm *k, struct scm *value);
 /* src/math.c */
 struct scm *greater_p (struct scm *x);
 struct scm *less_p (struct scm *x);
@@ -97,11 +108,9 @@ struct scm *lognot (struct scm *x);
 struct scm *logxor (struct scm *x);
 struct scm *ash (struct scm *n, struct scm *count);
 /* src/module.c */
-struct scm *make_module_type ();
-struct scm *module_printer (struct scm *module);
-struct scm *module_variable (struct scm *module, struct scm *name);
-struct scm *module_ref (struct scm *module, struct scm *name);
-struct scm *module_define_x (struct scm *module, struct scm *name, struct scm *value);
+struct scm *initial_module ();
+struct scm *current_module ();
+struct scm *set_current_module (struct scm *module);
 /* src/posix.c */
 struct scm *abort_ ();
 struct scm *exit_ (struct scm *x);
@@ -117,6 +126,7 @@ struct scm *getenv_ (struct scm *s);
 struct scm *setenv_ (struct scm *s, struct scm *v);
 struct scm *access_p (struct scm *file_name, struct scm *mode);
 struct scm *current_input_port ();
+struct scm *open_ (struct scm *file_name, struct scm *flags);
 struct scm *open_input_file (struct scm *file_name);
 struct scm *open_input_string (struct scm *string);
 struct scm *set_current_input_port (struct scm *port);
@@ -128,7 +138,9 @@ struct scm *set_current_error_port (struct scm *port);
 struct scm *chmod_ (struct scm *file_name, struct scm *mode);
 struct scm *isatty_p (struct scm *port);
 struct scm *primitive_fork ();
+struct scm *primitive_exit (struct scm *status);
 struct scm *execl_ (struct scm *file_name, struct scm *args);
+struct scm *execle_ (struct scm *file_name, struct scm *args, struct scm *env);
 struct scm *waitpid_ (struct scm *pid, struct scm *options);
 struct scm *current_time ();
 struct scm *gettimeofday_ ();
@@ -137,6 +149,7 @@ struct scm *getcwd_ ();
 struct scm *dup_ (struct scm *port);
 struct scm *dup2_ (struct scm *old, struct scm *new);
 struct scm *delete_file (struct scm *file_name);
+struct scm *uname_ ();
 /* src/reader.c */
 struct scm *read_input_file_env_ (struct scm *e, struct scm *a);
 struct scm *read_input_file_env (struct scm *a);
@@ -165,11 +178,18 @@ struct scm *read_string (struct scm *port);
 struct scm *string_append (struct scm *x);
 struct scm *string_length (struct scm *string);
 struct scm *string_ref (struct scm *str, struct scm *k);
+struct scm *string_set_x (struct scm *str, struct scm *k, struct scm *c);
 /* src/struct.c */
 struct scm *make_struct (struct scm *type, struct scm *fields, struct scm *printer);
 struct scm *struct_length (struct scm *x);
 struct scm *struct_ref (struct scm *x, struct scm *i);
 struct scm *struct_set_x (struct scm *x, struct scm *i, struct scm *e);
+/* src/variable.c */
+struct scm *make_variable (struct scm *var);
+struct scm *variable_p (struct scm *x);
+struct scm *variable_ref (struct scm *var);
+struct scm *variable_set_x (struct scm *var, struct scm *value);
+struct scm *variable_printer (struct scm *var);
 /* src/vector.c */
 struct scm *make_vector (struct scm *x);
 struct scm *vector_length (struct scm *x);
@@ -179,4 +199,13 @@ struct scm *vector_set_x (struct scm *x, struct scm *i, struct scm *e);
 struct scm *list_to_vector (struct scm *x);
 struct scm *vector_to_list (struct scm *v);
 
+/* This is a conditional compilation hack for M2-Planet in bootstrap
+   mode.  The following file will not be included in the M2-Planet build
+   of Mes, as M2-Planet will ignore the preprocessor directive.  Other
+   builds of Mes will include it.  The code in the file relies on system
+   interfaces supported by MesCC but not M2-Planet.  Note that we use
+   the full include path here, as otherwise NYACC can't find it when
+   this file is included from elsewhere (possibly a bug). */
+#include "mes/mescc-builtins.h"
+
 #endif /* __MES_BUILTINS_H */
