@@ -38,8 +38,6 @@ extern struct scm *cell_vm_begin_eval;
 extern struct scm *cell_vm_begin_expand;
 extern struct scm *cell_vm_begin_expand_eval;
 extern struct scm *cell_vm_begin_expand_macro;
-extern struct scm *cell_vm_begin_expand_primitive_load;
-extern struct scm *cell_vm_begin_primitive_load;
 extern struct scm *cell_vm_begin_read_input_file;
 extern struct scm *cell_vm_call_with_current_continuation2;
 extern struct scm *cell_vm_call_with_values2;
@@ -86,9 +84,7 @@ extern struct scm *cell_symbol_portable_macro_expand;
 extern struct scm *cell_symbol_sc_expander_alist;
 extern struct scm *cell_symbol_call_with_values;
 extern struct scm *cell_symbol_call_with_current_continuation;
-extern struct scm *cell_symbol_boot_module;
-extern struct scm *cell_symbol_current_module;
-extern struct scm *cell_symbol_primitive_load;
+extern struct scm *cell_symbol_current_environment;
 extern struct scm *cell_symbol_car;
 extern struct scm *cell_symbol_cdr;
 extern struct scm *cell_symbol_not_a_number;
@@ -102,7 +98,6 @@ extern struct scm *cell_symbol_buckets;
 extern struct scm *cell_symbol_builtin;
 extern struct scm *cell_symbol_frame;
 extern struct scm *cell_symbol_hashq_table;
-extern struct scm *cell_symbol_module;
 extern struct scm *cell_symbol_procedure;
 extern struct scm *cell_symbol_record_type;
 extern struct scm *cell_symbol_size;
@@ -115,6 +110,9 @@ extern struct scm *cell_symbol_compiler;
 extern struct scm *cell_symbol_arch;
 extern struct scm *cell_symbol_pmatch_car;
 extern struct scm *cell_symbol_pmatch_cdr;
+extern struct scm *cell_symbol_variable;
+extern struct scm *cell_symbol_standard_eval_closure;
+extern struct scm *cell_symbol_standard_interface_eval_closure;
 extern struct scm *cell_type_bytes;
 extern struct scm *cell_type_char;
 extern struct scm *cell_type_closure;
@@ -131,14 +129,17 @@ extern struct scm *cell_type_string;
 extern struct scm *cell_type_struct;
 extern struct scm *cell_type_symbol;
 extern struct scm *cell_type_values;
-extern struct scm *cell_type_variable;
+extern struct scm *cell_type_binding;
 extern struct scm *cell_type_vector;
 extern struct scm *cell_type_broken_heart;
 extern struct scm *cell_symbol_program;
 extern struct scm *cell_symbol_test;
 
-#define SYMBOL_MAX 114
+// CONSTANT SYMBOL_MAX 113
+#define SYMBOL_MAX 113
+
 #define CELL_UNSPECIFIED 7
-#define CELL_SYMBOL_RECORD_TYPE 82
+
+#define CELL_SYMBOL_RECORD_TYPE 77
 
 #endif /* __MES_SYMBOLS_H */
