@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * Mes --- Maxwell Equations of Software
- * Copyright © 2018,2019,2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2018,2019,2023,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of Mes.
  *
@@ -18,14 +18,10 @@
  * along with Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib-mini.h>
 #include <gnu/hurd.h>
 int main (int argc, char *argv[], char *envp[]);
 
-char **environ;
-int __stdin;
-int __stdout;
-int __stderr;
-
 void _exit (int status);
 
 void _hurd_start (void);
