@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -21,9 +22,16 @@
 #include <linux/syscall.h>
 #include <arch/syscall.h>
 #include <sys/stat.h>
+#include <fcntl.h>
 
 int
 mknod (char const *file_name, mode_t mode, dev_t dev)
 {
+#if defined (SYS_mknod)
   return _sys_call3 (SYS_mknod, (long) file_name, (long) mode, (long) dev);
+#elif defined (SYS_mknodat)
+  return _sys_call4 (SYS_mknodat, AT_FDCWD, (long) file_name, (long) mode, (long) dev);
+#else
+#error No usable mknod syscall
+#endif
 }
