@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -19,10 +19,11 @@
  */
 
 #include <stdio.h>
+#include <unistd.h>
 
 int
-fclose (FILE *stream)
+fclose (FILE * stream)
 {
-  int fd = (int)stream;
+  int fd = (long) stream;
   return close (fd);
 }
