@@ -21,9 +21,9 @@
 #include <stdio.h>
 
 int
-ferror (FILE *stream)
+ferror (FILE * stream)
 {
-  int fd = (int)stream;
+  int fd = (long) stream;
   if (fd == -1)
     return -1;
   return 0;
