@@ -18,10 +18,10 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 
 int
-puts (char const* s)
+puts (char const *s)
 {
   oputs (s);
   return oputs ("\n");
