@@ -21,8 +21,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if BZERO_INT
 int
+#else
+void
+#endif
 bzero (void *block, size_t size)
 {
-  return (int) (long) memset (block, 0, size);
+#if BZERO_INT
+  return (int) (long)
+#endif
+    memset (block, 0, size);
 }
