@@ -18,7 +18,8 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <errno.h>
 #include <time.h>
 #include <sys/time.h>
 
