@@ -24,6 +24,6 @@ int
 main ()
 {
   oputs ("\n");
-  oputs ("mes\n");
+  oputs ("Hello, GNU Mes\n");
   return 0;
 }
