@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -31,7 +31,7 @@ main (int argc, char *argv[])
   oputs ("argv0=");
   oputs (argv[0]);
   oputs ("\n");
-  if (strcmp (argv[0], "lib/tests/scaffold/54-argv"))
+  if (strncmp (argv[0], "lib/tests/scaffold/54-argv", 26))
     return 1;
 
   oputs ("t: *argv\"\n");
