@@ -20,7 +20,9 @@
 (define mes %version)
 
 (define (defined? x)
-  (module-variable (current-module) x))
+  ((lambda (v)
+     (if v (if (eq? (variable-ref v) *undefined*) #f #t) #f))
+   (core:hashq-ref (initial-module) x #f)))
 
 (define (cond-expand-expander clauses)
   (if (defined? (car (car clauses)))
