@@ -2,6 +2,7 @@
 
 ;;; GNU Mes --- Maxwell Equations of Software
 ;;; Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2023 Timothy Sample <samplet@ngyro.com>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -30,7 +31,9 @@
 (define mes %version)
 
 (define (defined? x)
-  (module-variable (current-module) x))
+  ((lambda (v)
+     (if v (if (eq? (variable-ref v) *undefined*) #f #t) #f))
+   (core:hashq-ref (initial-module) x #f)))
 
 (define (cond-expand-expander clauses)
   (if (defined? (car (car clauses)))
@@ -58,25 +61,35 @@
 (define (cadr x) (car (cdr x)))
 
 (define (map1 f lst)
-  (if (null? lst) (list)
-      (cons (f (car lst)) (map1 f (cdr lst)))))
+  (define (loop lst acc)
+    (if (null? lst)
+        (core:reverse! acc (list))
+        (loop (cdr lst) (cons (f (car lst)) acc))))
+  (loop lst (list)))
 
 (define (map f lst)
   (if (null? lst) (list)
       (cons (f (car lst)) (map f (cdr lst)))))
 
 (define (cons* . rest)
-  (if (null? (cdr rest)) (car rest)
-      (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
+  (define (loop lst acc)
+    (if (null? (cdr lst))
+        (core:reverse! acc (car lst))
+        (loop (cdr lst) (cons (car lst) acc))))
+  (loop rest (list)))
 
 (define (apply f h . t)
-  (if (null? t) (core:apply f h (current-module))
+  (if (null? t) (core:apply f h (current-environment))
       (apply f (apply cons* (cons h t)))))
 
 (define (append . rest)
-  (if (null? rest) '()
-      (if (null? (cdr rest)) (car rest)
-          (append2 (car rest) (apply append (cdr rest))))))
+  (define (loop lst acc)
+    (if (null? (cdr lst))
+        (core:reverse! acc (car lst))
+        (loop (cdr lst) (append-reverse (car lst) acc))))
+  (if (null? rest)
+      '()
+      (loop rest (list))))
 ;; end boot-01.scm
 
 ;; boot-02.scm
@@ -101,7 +114,7 @@
 ;; boot-03.scm
 (define guile? #f)
 (define mes? #t)
-(define (primitive-eval e) (core:eval e (current-module)))
+(define (primitive-eval e) (core:eval e (current-environment)))
 (define eval core:eval)
 
 (define (port-filename port) "<stdin>")
@@ -110,14 +123,6 @@
 (define (ftell port) 0)
 (define (false-if-exception x) x)
 
-(define (cons* . rest)
-  (if (null? (cdr rest)) (car rest)
-      (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
-
-(define (apply f h . t)
-  (if (null? t) (core:apply f h (current-module))
-      (apply f (apply cons* (cons h t)))))
-
 (define-macro (load file)
   (list 'begin
         (list 'if (list 'and (list getenv "MES_DEBUG")
@@ -131,11 +136,6 @@
 
 (define-macro (include file) (list 'load file))
 
-(define (append . rest)
-  (if (null? rest) '()
-      (if (null? (cdr rest)) (car rest)
-          (append2 (car rest) (apply append (cdr rest))))))
-
 (define %moduledir (string-append %datadir "/module/"))
 
 (include (string-append %moduledir "mes/type-0.mes"))
@@ -170,6 +170,9 @@
        (define (,(car module) . arguments) (main (command-line)))))
 
 (define-macro (use-modules . rest) #t)
+
+(define-macro (@ mod-name var-name) var-name)
+(define-macro (@@ mod-name var-name) var-name)
+
 ;; end boot-03.scm
 (primitive-load 0)
-(primitive-load 0)
