@@ -228,6 +228,11 @@
 ;; 2006/12/24 - bugfixes
 ;; 2006/12/01 - non-linear patterns, shared variables in OR, get!/set!
 
+;; Mes: We don't really have hygienic 'syntax-rules', so we need some
+;; helpers to make templates that introduce local bindings work properly
+;; when nested.  Essentially, all of the 'define-macro' forms are Mes
+;; workarounds.
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; force compile-time syntax errors with useful messages
 
@@ -332,6 +337,39 @@
 ;; multiple times) and IDS are the list of identifiers bound in the
 ;; pattern so far.
 
+(define-macro (match-two/field v proc p . x)
+  (let ((w (gensym)))
+    `(let ((,w (,proc ,v))) (match-one ,w ,p ,@x))))
+
+(define-macro (match-two/singleton v p sk fk i)
+  (let ((w (gensym)))
+    `(if (and (pair? ,v) (null? (cdr ,v)))
+         (let ((,w (car ,v)))
+           (match-one ,w ,p ((car ,v) (set-car! ,v)) ,sk ,fk ,i))
+         ,fk)))
+
+(define-macro (match-two/pair v p q sk fk i)
+  (let ((w (gensym))
+        (x (gensym)))
+    `(if (pair? ,v)
+         (let ((,w (car ,v)) (,x (cdr ,v)))
+           (match-one ,w ,p ((car ,v) (set-car! ,v))
+            (match-one ,x ,q ((cdr ,v) (set-cdr! ,v)) ,sk ,fk)
+            ,fk
+            ,i))
+         ,fk)))
+
+(define-macro (match-two/symbol v x sk fk i)
+  (let ((new-sym? (gensym)))
+    `(let-syntax
+         ((,new-sym?
+           (syntax-rules ,i
+             ((new-sym? ,x sk2 fk2) sk2)
+             ((new-sym? y sk2 fk2) fk2))))
+       (,new-sym? random-sym-to-match
+                  (let ((,x ,v)) (,@sk (,@i ,x)))
+                  (if (equal? ,v ,x) (,@sk ,i) ,fk)))))
+
 (define-syntax match-two
   (syntax-rules (_ ___ ..1 *** quote quasiquote ? $ = and or not set! get!)
     ((match-two v () g+s (sk ...) fk i)
@@ -356,20 +394,12 @@
      (let ((setter (lambda (x) (s ... x)))) (sk ... i)))
     ((match-two v (? pred . p) g+s sk fk i)
      (if (pred v) (match-one v (and . p) g+s sk fk i) fk))
-    ((match-two v (= proc p) . x)
-     (let ((w (proc v))) (match-one w p . x))
-     ;;(let ((W (proc v))) (match-one W p . x))
-     )
+    ((match-two v (= proc p) g+s sk fk i)
+     (match-two/field v proc p g+s sk fk i))
     ((match-two v (p ___ . r) g+s sk fk i)
      (match-extract-vars p (match-gen-ellipses v p r g+s sk fk i) i ()))
     ((match-two v (p) g+s sk fk i)
-     (if (and (pair? v) (null? (cdr v)))
-         (let ;;((w (car v)))
-             ((W (car v)))
-           ;;(match-one w p ((car v) (set-car! v)) sk fk i)
-           (match-one W p ((car v) (set-car! v)) sk fk i)
-           )
-         fk))
+     (match-two/singleton v p sk fk i))
     ((match-two v (p *** q) g+s sk fk i)
      (match-extract-vars p (match-gen-search v p q g+s sk fk i) i ()))
     ((match-two v (p *** . q) g+s sk fk i)
@@ -383,16 +413,7 @@
          (match-record-refs v rec 0 (p ...) g+s sk fk i)
          fk))
     ((match-two v (p . q) g+s sk fk i)
-     (if (pair? v)
-         (let ;;((w (car v)) (x (cdr v)))
-             ((W (car v)) (X (cdr v)))
-           (match-one ;;w p ((car v) (set-car! v))
-                      W p ((car v) (set-car! v))
-                      ;;(match-one x q ((cdr v) (set-cdr! v)) sk fk)
-                      (match-one X q ((cdr v) (set-cdr! v)) sk fk)
-                      fk
-                      i))
-         fk))
+     (match-two/pair v p q sk fk i))
     ((match-two v #(p ...) g+s . x)
      (match-vector v 0 () (p ...) . x))
     ((match-two v _ g+s (sk ...) fk i) (sk ... i))
@@ -400,21 +421,8 @@
     ;; new symbol, in which case we just bind it, or if it's an
     ;; already bound symbol or some other literal, in which case we
     ;; compare it with EQUAL?.
-    (;;(match-two v x g+s (sk ...) fk (id ...))
-     (match-two V X g+s (sk ...) fk (id ...))
-     (let-syntax
-         ((new-sym?
-           (syntax-rules (id ...)
-             ;;((new-sym? x sk2 fk2) sk2)
-             ((new-sym? X sk2 fk2) sk2)
-             ((new-sym? y sk2 fk2) fk2))))
-       (new-sym? random-sym-to-match
-                 ;;(let ((x v)) (sk ... (id ... x)))
-                 (let ((X V)) (sk ... (id ... X)))
-                 ;;(if (equal? v x) (sk ... (id ...)) fk)
-                 (if (equal? V X) (sk ... (id ...)) fk)
-                 )))
-    ))
+    ((match-two v x g+s (sk ...) fk (id ...))
+     (match-two/symbol v x (sk ...) fk (id ...)))))
 
 ;; QUASIQUOTE patterns
 
@@ -515,34 +523,47 @@
 ;; expects to see in the success body) to the reversed accumulated
 ;; list IDs.
 
+(define-macro (match-gen-ellipses/no-trail v p sk fk i id+lss)
+  (let ((ls (gensym))
+        (w (gensym))
+        (loop (gensym))
+        ;; Set all lists to empty.
+        (id+ls-init (map (lambda (id+ls)
+                           `(,(cdr id+ls) '()))
+                         id+lss))
+        ;; Bind all pattern variables to their lists.
+        (id+ls-let  (map (lambda (id+ls)
+                           `(,(car id+ls) (reverse ,(cdr id+ls))))
+                         id+lss))
+        ;; Cons each bound pattern variable onto their lists.
+        (id+ls-loop (map (lambda (id+ls)
+                           `(cons ,(car id+ls) ,(cdr id+ls)))
+                         id+lss)))
+    `(match-check-identifier
+      ,p
+      ;; simplest case equivalent to (p ...), just bind the list
+      (let ((,p ,v))
+        (if (list? ,p)
+            (,@sk ,i)
+            ,fk))
+      ;; simple case, match all elements of the list
+      (let ,loop ((,ls ,v) ,@id+ls-init)
+           (cond
+            ((null? ,ls)
+             (let (,@id+ls-let)
+               (,@sk ,i)))
+            ((pair? ,ls)
+             (let ((,w (car ,ls)))
+               (match-one ,w ,p ((car ,ls) (set-car! ,ls))
+                          (match-drop-ids (,loop (cdr ,ls) ,@id+ls-loop))
+                          ,fk ,i)))
+            (else
+             ,fk))))))
+
 (define-syntax match-gen-ellipses
   (syntax-rules ()
-    (;;(_ v p () g+s (sk ...) fk i ((id id-ls) ...))
-     (_ v P () g+s (sk ...) fk i ((id id-ls) ...))
-     (match-check-identifier
-      ;;p
-      P
-      ;; simplest case equivalent to (p ...), just bind the list
-      (let ;;((p v))
-          ((P v))
-        (if ;;(list? p)
-         (list? P)
-             (sk ... i)
-             fk))
-       ;; simple case, match all elements of the list
-       (let loop ((ls v) (id-ls '()) ...)
-         (cond
-           ((null? ls)
-            (let ((id (reverse id-ls)) ...) (sk ... i)))
-           ((pair? ls)
-            (let ;;((w (car ls)))
-                ((W (car ls)))
-              (match-one ;;w p ((car ls) (set-car! ls))
-                         W p ((car ls) (set-car! ls))
-                         (match-drop-ids (loop (cdr ls) (cons id id-ls) ...))
-                         fk i)))
-           (else
-            fk)))))
+    ((_ v p () g+s (sk ...) fk i ((id id-ls) ...))
+     (match-gen-ellipses/no-trail v p (sk ...) fk i ((id . id-ls) ...)))
     ((_ v p r g+s (sk ...) fk i ((id id-ls) ...))
      ;; general case, trailing patterns to match, keep track of the
      ;; remaining list length so we don't need any backtracking
@@ -723,6 +744,17 @@
 ;;
 ;; (match-extract-vars pattern continuation (ids ...) (new-vars ...))
 
+(define-macro (match-extract-vars/main p k i v)
+  (let ((p-ls (gensym)))
+    `(let-syntax
+         ((new-sym?
+           (syntax-rules ,i
+             ((new-sym? ,p sk fk) sk)
+             ((new-sym? any sk fk) fk))))
+       (new-sym? random-sym-to-match
+                 (,@k ((,p ,p-ls) . ,v))
+                 (,@k ,v)))))
+
 (define-syntax match-extract-vars
   (syntax-rules (_ ___ ..1 *** ? $ = quote quasiquote and or not get! set!)
     ((match-extract-vars (? pred . p) . x)
@@ -759,14 +791,7 @@
     ;; This is the main part, the only place where we might add a new
     ;; var if it's an unbound symbol.
     ((match-extract-vars p (k ...) (i ...) v)
-     (let-syntax
-         ((new-sym?
-           (syntax-rules (i ...)
-             ((new-sym? p sk fk) sk)
-             ((new-sym? any sk fk) fk))))
-       (new-sym? random-sym-to-match
-                 (k ... ((p p-ls) . v))
-                 (k ... v))))
+     (match-extract-vars/main p (k ...) (i ...) v))
     ))
 
 ;; Stepper used in the above so it can expand the CAR and CDR
@@ -845,22 +870,22 @@
 ;;     ((_ ((var value) ...) . body)
 ;;      (match-let/helper letrec () () ((var value) ...) . body))))
 
-;; (define-syntax match-let/helper
-;;   (syntax-rules ()
-;;     ((_ let ((var expr) ...) () () . body)
-;;      (let ((var expr) ...) . body))
-;;     ((_ let ((var expr) ...) ((pat tmp) ...) () . body)
-;;      (let ((var expr) ...)
-;;        (match-let* ((pat tmp) ...)
-;;          . body)))
-;;     ((_ let (v ...) (p ...) (((a . b) expr) . rest) . body)
-;;      (match-let/helper
-;;       let (v ... (tmp expr)) (p ... ((a . b) tmp)) rest . body))
-;;     ((_ let (v ...) (p ...) ((#(a ...) expr) . rest) . body)
-;;      (match-let/helper
-;;       let (v ... (tmp expr)) (p ... (#(a ...) tmp)) rest . body))
-;;     ((_ let (v ...) (p ...) ((a expr) . rest) . body)
-;;      (match-let/helper let (v ... (a expr)) (p ...) rest . body))))
+(define-syntax match-let/helper
+  (syntax-rules ()
+    ((_ %let ((var expr) ...) () () . body)
+     (%let ((var expr) ...) . body))
+    ((_ %let ((var expr) ...) ((pat tmp) ...) () . body)
+     (%let ((var expr) ...)
+       (match-let* ((pat tmp) ...)
+         . body)))
+    ((_ %let (v ...) (p ...) (((a . b) expr) . rest) . body)
+     (match-let/helper
+      %let (v ... (tmp expr)) (p ... ((a . b) tmp)) rest . body))
+    ((_ %let (v ...) (p ...) ((#(a ...) expr) . rest) . body)
+     (match-let/helper
+      %let (v ... (tmp expr)) (p ... (#(a ...) tmp)) rest . body))
+    ((_ %let (v ...) (p ...) ((a expr) . rest) . body)
+     (match-let/helper %let (v ... (a expr)) (p ...) rest . body))))
 
 (define-syntax match-named-let
   (syntax-rules ()
