@@ -21,7 +21,7 @@
 #include <stdio.h>
 
 int
-main (int argc, char *argv[])
+main (int argc, char **argv)
 {
   eputs ("Hello, Mescc!\n");
   return 42;
