@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © Timothy Sample 2022 <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
  *
@@ -121,16 +122,29 @@ set_cdr_x (struct scm *x, struct scm *e)
 }
 
 struct scm *
-set_env_x (struct scm *x, struct scm *e, struct scm *a)
+set_x (struct scm *x, struct scm *e, int define_p)
 {
-  struct scm *p;
-  if (x->type == TVARIABLE)
-    p = x->variable;
+  struct scm *binding;
+
+  if (x->type == TBINDING)
+    binding = x;
   else
-    p = assert_defined (x, module_variable (a, x));
-  if (p->type != TPAIR)
-    error (cell_symbol_not_a_pair, cons (p, x));
-  return set_cdr_x (p, e);
+    binding = lookup_binding (x, cell_f);
+
+  if (binding == cell_f)
+    return error (cell_symbol_unbound_variable, x);
+
+  if (binding->lexical_p != 0)
+    set_cdr_x (binding->binding, e);
+  else
+    {
+      struct scm *variable = binding->binding->cdr;
+      if (define_p == 0 && variable_ref (variable) == cell_undefined)
+        return error (cell_symbol_unbound_variable, binding->binding->car);
+      variable_set_x (binding->binding->cdr, e);
+    }
+
+  return cell_unspecified;
 }
 
 struct scm *
@@ -149,16 +163,24 @@ make_closure_ (struct scm *args, struct scm *body, struct scm *a)       /*:((int
 }
 
 struct scm *
-make_variable_ (struct scm *var)        /*:((internal)) */
+make_binding_ (struct scm *handle, long lexical_p)      /*:((internal)) */
 {
-  return make_cell (TVARIABLE, var, 0);
+  struct scm *binding = make_cell (TBINDING, handle, 0);
+  binding->lexical_p = lexical_p;
+  return binding;
+}
+
+struct scm *
+make_binding (struct scm *name, struct scm *variable)
+{
+  return make_binding_ (cons (name, variable), 0);
 }
 
 struct scm *
 macro_get_handle (struct scm *name)     /*:((internal)) */
 {
   if (name->type == TSYMBOL)
-    return hashq_get_handle (g_macros, name, cell_nil);
+    return hashq_get_handle (g_macros, name);
   return cell_f;
 }
 
@@ -193,6 +215,34 @@ push_cc (struct scm *p1, struct scm *p2, struct scm *a, struct scm *c)  /*:((int
   return cell_unspecified;
 }
 
+struct scm *
+lookup_binding (struct scm *name, struct scm *define_p)
+{
+  struct scm *handle = assq (name, R0);
+  if (handle != cell_f)
+    return make_binding_ (handle, 1);
+
+  struct scm *variable = current_module_variable (name, define_p);
+  if (variable != cell_f)
+    return make_binding_ (cons (name, variable), 0);
+
+  return cell_f;
+}
+
+struct scm *
+lookup_value (struct scm *name)
+{
+  struct scm *binding = lookup_binding (name, cell_f);
+  if (binding != cell_f)
+    {
+      if (binding->lexical_p != 0)
+        return binding->binding->cdr;
+      else
+        return variable_ref (binding->binding->cdr);
+    }
+  return cell_undefined;
+}
+
 struct scm *
 add_formals (struct scm *formals, struct scm *x)
 {
@@ -227,69 +277,105 @@ formal_p (struct scm *x, struct scm *formals)   /*:((internal)) */
   return formals->type == TPAIR;
 }
 
-struct scm *
-expand_variable_ (struct scm *x, struct scm *formals, int top_p)        /*:((internal)) */
+void
+expand_variable_ (int top_p)        /*:((internal)) */
 {
   struct scm *a;
   struct scm *f;
   struct scm *v;
-  while (x->type == TPAIR)
+
+  /* First add all internal definitions to the current list of
+     formals. */
+  v = R1;
+  while (v->type == TPAIR)
     {
-      a = x->car;
+      a = v->car;
+      if (a == cell_symbol_quote)
+        break;
       if (a->type == TPAIR)
         {
-          if (a->car == cell_symbol_lambda)
+          if (a->car == cell_symbol_define || a->car == cell_symbol_define_macro)
             {
-              f = a->cdr->car;
-              formals = add_formals (formals, f);
+              if (a->cdr->car->type == TPAIR)
+                R2 = cons (a->cdr->car->car, R2);
+              else
+                R2 = cons (a->cdr->car, R2);
             }
-          else if (a->car == cell_symbol_define || a->car == cell_symbol_define_macro)
-            {
-              f = a->cdr->car;
-              formals = add_formals (formals, f);
-            }
-          if (a->car != cell_symbol_quote)
-            expand_variable_ (a, formals, 0);
         }
+      v = v->cdr;
+    }
+
+  /* Now do the expansion. */
+  while (R1->type == TPAIR)
+    {
+      a = R1->car;
+      if (a->type == TPAIR)
+        R3 = cons (cons (a, R2), R3);
       else
         {
           if (a == cell_symbol_lambda)
             {
-              f = x->cdr->car;
-              formals = add_formals (formals, f);
-              x = x->cdr;
+              f = R1->cdr->car;
+              R2 = add_formals (R2, f);
+              R1 = R1->cdr;
             }
           else if (a == cell_symbol_define || a == cell_symbol_define_macro)
             {
-              f = x->cdr->car;
-              if (top_p != 0 && f->type == TPAIR)
-                f = f->cdr;
-              formals = add_formals (formals, f);
-              x = x->cdr;
+              f = R1->cdr->car;
+              if (top_p != 0)
+                {
+                  if (f->type == TPAIR)
+                    f = f->cdr;
+                  else
+                    f = cell_nil;
+                }
+              R2 = add_formals (R2, f);
+              R1 = R1->cdr;
             }
           else if (a == cell_symbol_quote)
-            return cell_unspecified;
+            return;
           else if (a->type == TSYMBOL
-                   && a != cell_symbol_boot_module
-                   && a != cell_symbol_current_module
-                   && a != cell_symbol_primitive_load
-                   && formal_p (x->car, formals) == 0)
+                   && a != cell_symbol_current_environment
+                   && formal_p (a, R2) == 0)
             {
-              v = module_variable (R0, a);
+              v = lookup_binding (R1->car, cell_f);
               if (v != cell_f)
-                x->car = make_variable_ (v);
+                R1->car = v;
+              else
+                {
+                  /* Lookup the binding again, but this time make a
+                     local definition in case the name becomes bound in
+                     the future. */
+                  R1->car = lookup_binding (R1->car, cell_t);
+                }
             }
         }
-      x = x->cdr;
+      R1 = R1->cdr;
       top_p = 0;
     }
-  return cell_unspecified;
 }
 
 struct scm *
 expand_variable (struct scm *x, struct scm *formals)    /*:((internal)) */
 {
-  return expand_variable_ (x, formals, 1);
+  gc_push_frame ();
+
+  R1 = x;
+  R2 = formals;
+  R3 = cell_nil;
+  expand_variable_ (1);
+
+  while (R3->type == TPAIR)
+    {
+      R1 = R3->car->car;
+      R2 = R3->car->cdr;
+      R3 = R3->cdr;
+      expand_variable_ (0);
+    }
+
+  gc_pop_frame ();
+
+  return cell_unspecified;
 }
 
 struct scm *
@@ -398,9 +484,6 @@ eval_apply:
     goto eval_pmatch_cdr;
   else if (R3 == cell_vm_macro_expand_define_macro)
     goto macro_expand_define_macro;
-  else if (R3 == cell_vm_begin_primitive_load)
-    goto begin_primitive_load;
-
   else if (R3 == cell_vm_evlis)
     goto evlis;
   else if (R3 == cell_vm_apply)
@@ -415,8 +498,6 @@ eval_apply:
     goto begin;
   else if (R3 == cell_vm_begin_expand)
     goto begin_expand;
-  else if (R3 == cell_vm_begin_expand_primitive_load)
-    goto begin_expand_primitive_load;
   else if (R3 == cell_vm_if)
     goto vm_if;
   else if (R3 == cell_vm_call_with_values2)
@@ -512,16 +593,11 @@ apply:
           R1 = R1->cdr;
           goto call_with_values;
         }
-      if (c == cell_symbol_current_module)
+      if (c == cell_symbol_current_environment)
         {
           R1 = R0;
           goto vm_return;
         }
-      if (c == cell_symbol_boot_module)
-        {
-          R1 = M0;
-          goto vm_return;
-        }
     }
   else if (t == TPAIR)
     {
@@ -548,6 +624,22 @@ eval:
   if (t == TPAIR)
     {
       c = R1->car;
+
+      /* If the car is a bound identifier, we want to dispatch on the
+         value to which it is bound. */
+      if (c->type == TBINDING)
+        {
+          if (c->lexical_p != 0)
+            R1->car = c->binding->cdr;
+          else
+            R1->car = variable_ref (c->binding->cdr);
+
+          if (R1->car == cell_undefined)
+            return error (cell_symbol_unbound_variable, c->binding->car);
+        }
+
+      c = R1->car;
+
       if (c == cell_symbol_pmatch_car)
         {
           push_cc (R1->cdr->car, R1, R0, cell_vm_eval_pmatch_car);
@@ -592,7 +684,7 @@ eval:
           push_cc (R1->cdr->cdr->car, R1, R0, cell_vm_eval_set_x);
           goto eval;
         eval_set_x:
-          R1 = set_env_x (R2->cdr->car, R1, R0);
+          R1 = set_x (R2->cdr->car, R1, 0);
           goto vm_return;
         }
       else if (c == cell_vm_macro_expand)
@@ -630,9 +722,9 @@ eval:
                       }
                     else
                       {
-                        entry = module_variable (R0, name);
-                        if (entry == cell_f)
-                          module_define_x (M0, name, cell_f);
+                        /* Ensure this name is bound in the current
+                           module. */
+                        lookup_binding (name, cell_t);
                       }
                   }
                 R2 = R1;
@@ -644,17 +736,32 @@ eval:
                   }
                 else
                   {
-                    p = pairlis (R1->cdr->car, R1->cdr->car, R0);
                     formals = R1->cdr->car->cdr;
                     body = R1->cdr->cdr;
 
                     if (macro_p != 0 || global_p != 0)
                       expand_variable (body, formals);
+
+                    /* The GC may have moved 'formals' and 'body' during
+                       variable expansion, so get fresh pointers. */
+                    formals = R1->cdr->car->cdr;
+                    body = R1->cdr->cdr;
+                    p = pairlis (R1->cdr->car, R1->cdr->car, R0);
+
                     R1 = cons (cell_symbol_lambda, cons (formals, body));
                     push_cc (R1, R2, p, cell_vm_eval_define);
                     goto eval;
                   }
               eval_define:
+                /* These may have been clobbered by an inline define
+                   during evaluation, so they must be recomputed. */
+                global_p = 0;
+                if (R0->car->car != cell_closure)
+                  global_p = 1;
+                macro_p = 0;
+                if (R2->car == cell_symbol_define_macro)
+                  macro_p = 1;
+
                 name = R2->cdr->car;
                 aa = R2->cdr->car;
                 if (aa->type == TPAIR)
@@ -667,17 +774,19 @@ eval:
                   }
                 else if (global_p != 0)
                   {
-                    entry = module_variable (R0, name);
-                    set_cdr_x (entry, R1);
+                    set_x (name, R1, 1);
                   }
                 else
                   {
                     entry = cons (name, R1);
                     aa = cons (entry, cell_nil);
+                    /* Push the definition onto the current lexical
+                       environment, but keep the first element (named
+                       '*closure*') pointing to the rest of the
+                       environment. */
                     set_cdr_x (aa, cdr (R0));
                     set_cdr_x (R0, aa);
-                    cl = module_variable (R0, cell_closure);
-                    set_cdr_x (cl, aa);
+                    set_cdr_x (car (R0), aa);
                   }
                 R1 = cell_unspecified;
                 goto vm_return;
@@ -695,21 +804,27 @@ eval:
     }
   else if (t == TSYMBOL)
     {
-      if (R1 == cell_symbol_boot_module)
-        goto vm_return;
-      if (R1 == cell_symbol_current_module)
+      if (R1 == cell_symbol_current_environment)
         goto vm_return;
       if (R1 == cell_symbol_begin)
         goto vm_return;
       if (R1 == cell_symbol_call_with_current_continuation)
         goto vm_return;
-      R1 = assert_defined (R1, module_ref (R0, R1));
+      R1 = assert_defined (R1, lookup_value (R1));
       goto vm_return;
     }
-  else if (t == TVARIABLE)
+  else if (t == TBINDING)
     {
-      x = R1->variable;
-      R1 = x->cdr;
+      name = R1->binding->car;
+
+      if (R1->lexical_p != 0)
+        R1 = R1->binding->cdr;
+      else
+        R1 = variable_ref (R1->binding->cdr);
+
+      if (R1 == cell_undefined)
+        return error (cell_symbol_unbound_variable, name);
+
       goto vm_return;
     }
   else if (t == TBROKEN_HEART)
@@ -777,13 +892,13 @@ macro_expand:
           macro = macro_get_handle (cell_symbol_portable_macro_expand);
           if (macro != cell_f)
             {
-              expanders = module_ref (R0, cell_symbol_sc_expander_alist);
+              expanders = lookup_value (cell_symbol_sc_expander_alist);
               if (expanders != cell_undefined)
                 {
                   macro = assq (R1->car, expanders);
                   if (macro != cell_f)
                     {
-                      sc_expand = module_ref (R0, cell_symbol_macro_expand);
+                      sc_expand = lookup_value (cell_symbol_macro_expand);
                       R2 = R1;
                       if (sc_expand != cell_undefined && sc_expand != cell_f)
                         {
@@ -819,19 +934,6 @@ begin:
   while (R1 != cell_nil)
     {
       gc_check ();
-      if (R1->type == TPAIR)
-        {
-          if (R1->car->car == cell_symbol_primitive_load)
-            {
-              program = cons (R1->car, cell_nil);
-              push_cc (program, R1, R0, cell_vm_begin_primitive_load);
-              goto begin_expand;
-            begin_primitive_load:
-              R2->car = R1;
-              R1 = R2;
-            }
-        }
-
       if (R1->type == TPAIR)
         {
           a = R1->car;
@@ -869,38 +971,6 @@ begin_expand:
           if (a->type == TPAIR)
             if (R1->car->car == cell_symbol_begin)
               R1 = append2 (R1->car->cdr, R1->cdr);
-          if (R1->car->car == cell_symbol_primitive_load)
-            {
-              push_cc (R1->car->cdr->car, R1, R0, cell_vm_begin_expand_primitive_load);
-              goto eval;
-            begin_expand_primitive_load:
-              if ((R1->type == TNUMBER) && R1->value == 0)
-                0;
-              else if (R1->type == TSTRING)
-                input = set_current_input_port (open_input_file (R1));
-              else if (R1->type == TPORT)
-                input = set_current_input_port (R1);
-              else
-                {
-                  eputs ("begin_expand failed, R1=");
-                  display_error_ (R1);
-                  assert_msg (0, "begin-expand-boom 0");
-                }
-
-              push_cc (input, R2, R0, cell_vm_return);
-              x = read_input_file_env (R0);
-              if (g_debug > 5)
-                module_printer (M0);
-              gc_pop_frame ();
-              input = R1;
-              R1 = x;
-              set_current_input_port (input);
-              R1 = cons (cell_symbol_begin, R1);
-              R2->car = R1;
-              R1 = R2;
-              goto begin_expand_while;
-              continue; /* FIXME: M2-PLanet */
-            }
         }
 
       push_cc (R1->car, R1, R0, cell_vm_begin_expand_macro);
@@ -914,6 +984,24 @@ begin_expand:
           continue; /* FIXME: M2-PLanet */
         }
       R1 = R2;
+
+      /* If we expand a 'define' form that refers to itself, and it also
+         reuses a name higher up in the module chain, the self-reference
+         will be bound to the variable from the other module.  We hack
+         around this by binding the name in the current module before
+         expansion.  */
+      if (R1->type == TPAIR
+          && R1->car->type == TPAIR
+          && R1->car->car == cell_symbol_define)
+        {
+          /* Split the '&&' expression up to prevent a segfault when
+             compiled with M2-Planet. */
+          if (R1->car->cdr->type == TPAIR
+              && R1->car->cdr->car->type == TPAIR)
+            lookup_binding (R1->car->cdr->car->car, cell_t);
+        }
+
+
       expand_variable (R1->car, cell_nil);
       push_cc (R1->car, R1, R0, cell_vm_begin_expand_eval);
       goto eval;
@@ -944,14 +1032,12 @@ if_expr:
   goto vm_return;
 
 call_with_current_continuation:
-  gc_push_frame ();
   x = make_continuation (g_continuations);
   g_continuations = g_continuations + 1;
   v = make_vector_ (STACK_SIZE - g_stack, cell_unspecified);
   for (i = g_stack; i < STACK_SIZE; i = i + 1)
     vector_set_x_ (v, i - g_stack, g_stack_array[i]);
   x->continuation = v;
-  gc_pop_frame ();
   push_cc (cons (R1->car, cons (x, cell_nil)), x, R0, cell_vm_call_with_current_continuation2);
   goto apply;
 call_with_current_continuation2:
@@ -967,6 +1053,8 @@ call_with_values:
 call_with_values2:
   if (R1->type == TVALUES)
     R1 = R1->cdr;
+  else
+    R1 = cons (R1, cell_nil);
   R1 = cons (R2->cdr->car, R1);
   goto apply;
 
@@ -984,3 +1072,39 @@ apply (struct scm *f, struct scm *x, struct scm *a)     /*:((internal)) */
   R3 = cell_vm_apply;
   return eval_apply ();
 }
+
+struct scm *
+primitive_load (struct scm *filename)     /*:((arity . 1))*/
+{
+  struct scm *input;
+
+  if ((filename->type == TNUMBER) && filename->value == 0)
+    input = current_input_port ();
+  else if (filename->type == TSTRING)
+    input = set_current_input_port (open_input_file (filename));
+  else if (filename->type == TPORT)
+    input = set_current_input_port (filename);
+  else
+    {
+      eputs ("primitive_load failed, filename=");
+      display_error_ (filename);
+      assert_msg (0, "primitive-load-boom 0");
+    }
+
+  struct scm *forms = read_input_file_env (cell_nil);
+  forms = cons (cell_symbol_begin, forms);
+  set_current_input_port (input);
+
+  struct scm *env = cell_nil;
+  env = cons (cons (cell_symbol_program, forms), env);
+
+  gc_push_frame ();
+  /* Store 'input' in R2 so it does not get GCed during evaluation. */
+  push_cc (forms, cell_unspecified, env, cell_unspecified);
+  R3 = cell_vm_begin_expand;
+  struct scm *result = eval_apply ();
+  input = R2;
+  gc_pop_frame ();
+
+  return result;
+}
