@@ -2,6 +2,7 @@
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2016,2017,2018,2019,2020,2021,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  * Copyright © 2022 Gabriel Wicki <gabriel@erlikon.ch>
+ * Copyright © 2023 Timothy Sample <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
  *
@@ -52,7 +53,7 @@ gc_init ()
 #if SYSTEM_LIBC
   ARENA_SIZE = 100000000;       /* 2.3GiB */
 #elif ! __M2__
-  ARENA_SIZE = 300000;          /* 32b: 3MiB, 64b: 6 MiB */
+  ARENA_SIZE = 2400000;         /* 32b: 24MiB, 64b: 48 MiB */
 #else
   ARENA_SIZE = 20000000;
 #endif
@@ -239,18 +240,12 @@ bytes_cells (size_t length)
 }
 
 struct scm *
-make_bytes (char const *s, size_t length)
+make_bytes (size_t length)
 {
   size_t size = bytes_cells (length);
   struct scm *x = alloc (size);
   x->type = TBYTES;
   x->length = length;
-  char *p = cell_bytes (x);
-  if (length == 0)
-    p[0] = 0;
-  else
-    memcpy (p, s, length);
-
   return x;
 }
 
@@ -290,7 +285,9 @@ make_string (char const *s, size_t length)
   if (length > MAX_STRING)
     assert_max_string (length, "make_string", s);
   struct scm *x = make_pointer_cell (TSTRING, length, 0);
-  struct scm *v = make_bytes (s, length + 1);
+  struct scm *v = make_bytes (length + 1);
+  char *p = cell_bytes (v);
+  memcpy (p, s, length + 1);
   x->cdr = v;
   return x;
 }
@@ -389,7 +386,7 @@ gc_cellcpy (struct scm *dest, struct scm *src, size_t n)
       if (t == TMACRO
           || t == TPAIR
           || t == TREF
-          || t == TVARIABLE)
+          || t == TBINDING)
         dest->car_value = a - dist;
       else
         dest->car_value = a;
@@ -460,7 +457,10 @@ gc_flip ()
   g_symbols = g_symbols - dist;
   g_macros = g_macros - dist;
   g_ports = g_ports - dist;
+  scm_hash_table_type = scm_hash_table_type - dist;
+  scm_variable_type = scm_variable_type - dist;
   M0 = M0 - dist;
+  M1 = M1 - dist;
 
   long i;
   for (i = g_stack; i < STACK_SIZE; i = i + 1)
@@ -546,7 +546,7 @@ gc_loop (struct scm *scan)
       if (t == TMACRO
           || t == TPAIR
           || t == TREF
-          || t == TVARIABLE)
+          || t == TBINDING)
         /* *INDENT-ON* */
         {
           car = gc_copy (scan->car);
@@ -631,7 +631,10 @@ gc_ ()
   g_symbols = gc_copy (g_symbols);
   g_macros = gc_copy (g_macros);
   g_ports = gc_copy (g_ports);
+  scm_hash_table_type = gc_copy (scm_hash_table_type);
+  scm_variable_type = gc_copy (scm_variable_type);
   M0 = gc_copy (M0);
+  M1 = gc_copy (M1);
 
   long i;
   for (i = g_stack; i < STACK_SIZE; i = i + 1)
@@ -740,6 +743,7 @@ gc_dump_state ()
   gc_dump_register ("R2", R2);
   gc_dump_register ("R3", R3);
   gc_dump_register ("M0", M0);
+  gc_dump_register ("M1", M1);
   gc_dump_register ("g_symbols", g_symbols);
   gc_dump_register ("g_symbol_max", g_symbol_max);
   gc_dump_register ("g_macros", g_macros);
@@ -797,7 +801,7 @@ gc_dump_arena (struct scm *cells, long size)
               if (t == TMACRO
                   || t == TPAIR
                   || t == TREF
-                  || t == TVARIABLE)
+                  || t == TBINDING)
                 {
                   dumps (ltoa ((cells->car - dist) / M2_CELL_SIZE));
                   /* dumps ("["); dumps (ltoa (a)); dumps ("]"); */
