@@ -2,6 +2,7 @@
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2016,2017,2018,2019,2020,2021,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
+ * Copyright © 2022 Timothy Sample <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
  *
@@ -27,6 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
+#include <sys/utsname.h>
 #include <time.h>
 
 struct scm *
@@ -45,6 +47,25 @@ mes_environment (int argc, char **argv)
 {
   struct scm *a = init_symbols ();
 
+  /* These are symbols that the evaluator treats specially.  We bind
+     them to themselves so that they can be looked up and bound at
+     expansion time. */
+  a = acons (cell_symbol_call_with_current_continuation,
+             cell_symbol_call_with_current_continuation, a);
+  a = acons (cell_symbol_call_with_values,
+             cell_symbol_call_with_values, a);
+  a = acons (cell_symbol_current_environment,
+             cell_symbol_current_environment, a);
+  a = acons (cell_symbol_lambda, cell_symbol_lambda, a);
+  a = acons (cell_symbol_pmatch_car, cell_symbol_pmatch_car, a);
+  a = acons (cell_symbol_pmatch_cdr, cell_symbol_pmatch_cdr, a);
+  a = acons (cell_symbol_quote, cell_symbol_quote, a);
+  a = acons (cell_symbol_begin, cell_symbol_begin, a);
+  a = acons (cell_symbol_if, cell_symbol_if, a);
+  a = acons (cell_symbol_set_x, cell_symbol_set_x, a);
+  a = acons (cell_symbol_define, cell_symbol_define, a);
+  a = acons (cell_symbol_define_macro, cell_symbol_define_macro, a);
+
   char *compiler = "gnuc";
 #if __MESC__
   compiler = "mesc";
@@ -88,7 +109,7 @@ try_open_boot (char *file_name, char const *boot, char const *location)
   strcpy (file_name + strlen (file_name), boot);
   if (g_debug > 1)
     {
-      eputs ("mes: reading boot-0 [");
+      eputs ("mes: reading boot [");
       eputs (location);
       eputs ("]: ");
       eputs (file_name);
@@ -97,7 +118,7 @@ try_open_boot (char *file_name, char const *boot, char const *location)
   int fd = mes_open (file_name, O_RDONLY, 0);
   if (g_debug != 0 && fd > 0)
     {
-      eputs ("mes: read boot-0: ");
+      eputs ("mes: read boot: ");
       eputs (file_name);
       eputs ("\n");
     }
@@ -114,7 +135,7 @@ open_boot ()
   if (getenv ("MES_BOOT") != 0)
     strcpy (boot, getenv ("MES_BOOT"));
   else
-    strcpy (boot, "boot-0.scm");
+    strcpy (boot, "boot-5.scm");
   if (getenv ("MES_PREFIX") != 0)
     {
       strcpy (g_datadir, getenv ("MES_PREFIX"));
@@ -167,12 +188,14 @@ void
 init ()
 {
   __execl_c_argv = malloc (1024 * sizeof (char *));     /* POSIX minimum: 4096 */
+  __execle_c_env = malloc (1024 * sizeof (char *));
   __gettimeofday_time = malloc (sizeof (struct timeval));
   __get_internal_run_time_ts = malloc (sizeof (struct timespec));
   __open_boot_buf = malloc (PATH_MAX);
   __open_boot_file_name = malloc (PATH_MAX);
   __reader_read_char_buf = malloc (10);
   __setenv_buf = malloc (1024);
+  __uts = malloc (sizeof (struct utsname));
   g_datadir = malloc (1024);
   g_start_time = malloc (sizeof (struct timespec));
   memset (g_start_time, 0, sizeof (struct timespec));
@@ -196,10 +219,15 @@ main (int argc, char **argv)
   a = mes_builtins (a);
   a = init_time (a);
   M0 = make_initial_module (a);
+  M1 = cell_f;
+  R0 = cell_nil;
   g_macros = make_hash_table_ (0);
 
   if (g_debug > 5)
-    module_printer (M0);
+    {
+      eputs ("initial module obarray\n");
+      hash_table_printer (M0);
+    }
 
   struct scm *program = read_boot ();
   R0 = acons (cell_symbol_program, program, R0);
@@ -223,7 +251,10 @@ main (int argc, char **argv)
   if (g_debug != 0)
     {
       if (g_debug > 5)
-        module_printer (M0);
+        {
+          eputs ("initial module obarray\n");
+          hash_table_printer (M0);
+        }
 
       if (g_debug < 3)
         gc_stats_ ("\ngc run");
